@@ -144,23 +144,25 @@ public:
      */
     int iconSizeDefault() const; // KDE5: hide from public API. Doesn't make sense to export this, and it isn't used.
 
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * This allows you to enable or disable the context menu.
      *
      * @param enable If false, then the context menu will be disabled
-     * @deprecated use setContextMenuPolicy()
+     * @deprecated Since 5.0, use setContextMenuPolicy()
      */
-#ifndef KXMLGUI_NO_DEPRECATED
-    KXMLGUI_DEPRECATED void setContextMenuEnabled(bool enable = true);
+    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use QWidget::setContextMenuPolicy(Qt::ContextMenuPolicy)")
+    void setContextMenuEnabled(bool enable = true);
 #endif
 
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Returns the context menu enabled flag
      * @return true if the context menu is disabled
-     * @deprecated use contextMenuPolicy()
+     * @deprecated Since 5.0, use contextMenuPolicy()
      */
-#ifndef KXMLGUI_NO_DEPRECATED
-    KXMLGUI_DEPRECATED bool contextMenuEnabled() const;
+    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use QWidget::contextMenuPolicy()")
+    bool contextMenuEnabled() const;
 #endif
 
     /**
@@ -174,12 +176,13 @@ public:
      */
     void applySettings(const KConfigGroup &cg);
 
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Sets the XML gui client.
-     * @deprecated use addXMLGUIClient()
+     * @deprecated Since 5.0, use addXMLGUIClient()
      */
-#ifndef KXMLGUI_NO_DEPRECATED
-    KXMLGUI_DEPRECATED void setXMLGUIClient(KXMLGUIClient *client);
+    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use KToolBar::addXMLGUIClient(KXMLGUIClient *)")
+    void setXMLGUIClient(KXMLGUIClient *client);
 #endif
 
     /**
@@ -207,7 +210,7 @@ public:
     /**
      * Reimplemented to support context menu activation on disabled tool buttons.
      */
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
     /**
      * Returns whether the toolbars are currently editable (drag & drop of actions).
@@ -242,17 +245,17 @@ protected Q_SLOTS:
     virtual void slotMovableChanged(bool movable);
 
 protected:
-    void contextMenuEvent(QContextMenuEvent *) Q_DECL_OVERRIDE;
-    void actionEvent(QActionEvent *) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *) override;
+    void actionEvent(QActionEvent *) override;
 
     // Draggable toolbar configuration
-    void dragEnterEvent(QDragEnterEvent *) Q_DECL_OVERRIDE;
-    void dragMoveEvent(QDragMoveEvent *) Q_DECL_OVERRIDE;
-    void dragLeaveEvent(QDragLeaveEvent *) Q_DECL_OVERRIDE;
-    void dropEvent(QDropEvent *) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+    void dragEnterEvent(QDragEnterEvent *) override;
+    void dragMoveEvent(QDragMoveEvent *) override;
+    void dragLeaveEvent(QDragLeaveEvent *) override;
+    void dropEvent(QDropEvent *) override;
+    void mousePressEvent(QMouseEvent *) override;
+    void mouseMoveEvent(QMouseEvent *) override;
+    void mouseReleaseEvent(QMouseEvent *) override;
 
 private:
     class Private;
